@@ -4,7 +4,7 @@ gbp <- function(y, se.or.n, covariates, mean.PriorDist, model, intercept, confid
 ######
 gbp <- function(y, se.or.n, covariates, mean.PriorDist, model = "gaussian", 
                         intercept = TRUE, confidence.lvl = 0.95, 
-                        n.AR = 0, n.AR.factor = 4, trial.scale = NA, save.result = TRUE, 
+                        n.AR = 0, n.AR.factor = 4, trial.scale = 1.3, save.result = TRUE, 
                         normal.CI = FALSE, t = 0, u = 1) {
 
   ##input checks
@@ -369,7 +369,9 @@ plot.gbp <- function(x, sort = TRUE, ...) {
   ylim.low <- ifelse(min(po.low, y) >= 0, 0.8 * min(po.low, y), 1.2 * min(po.low, y))
   ylim.upp <- ifelse(max(po.upp, y) >= 0, 1.2 * max(po.upp, y), 0.8 * max(po.upp, y))
   
-  par(fig = c(0.25, 1, 0.5, 1), xaxs = "r", yaxs = "r", mai = c(0.5, 0.5, 0.5, 0.3), las = 1, ps = 13)
+  old.par1 <- par(fig = c(0.25, 1, 0.5, 1), xaxs = "r", yaxs = "r", 
+                mai = c(0.5, 0.5, 0.5, 0.3), las = 1, ps = 13)
+  on.exit(par(old.par1))
 
   if (x$model != "gr") {
     se <- sqrt(y * (1 - y) / se)
@@ -406,9 +408,9 @@ plot.gbp <- function(x, sort = TRUE, ...) {
     points(coords, pch=0)
   })
 
-  par(fig = c(0, 1, 0, 0.5), xaxs = "r", yaxs = "r", mai = c(0.8, 0.7, 0.5, 0.3), las = 1, 
-      ps = 13, new = TRUE)  
-
+  old.par2 <- par(fig = c(0, 1, 0, 0.5), xaxs = "r", yaxs = "r", 
+                mai = c(0.8, 0.7, 0.5, 0.3), las = 1, ps = 13, new = TRUE)
+  on.exit(par(old.par2))
 
   if (sort == TRUE) {
     if (x$model == "gr") {
@@ -443,8 +445,10 @@ plot.gbp <- function(x, sort = TRUE, ...) {
   }
 
   if (x$model == "br" & length(x$weight) != 1) { 
-    par(fig = c(0, 0.35, 0.5, 1), xaxs = "r", yaxs = "r", mai = c(0.4, 0.1, 0.5, 0), las = 1, ps = 9,
-        oma = c(0, 0, 0, 0), new = TRUE)  
+    old.par3 <- par(fig = c(0, 0.35, 0.5, 1), xaxs = "r", yaxs = "r", 
+                   mai = c(0.4, 0.1, 0.5, 0), las = 1, ps = 9,
+                   oma = c(0, 0, 0, 0), new = TRUE)
+    on.exit(par(old.par3))
     plot(1, type="n", axes=F, xlab="", ylab="")
     legend("topleft", pch = c(19, 1, NA, NA, NA,0), col = c(2, 1, 4,"darkviolet", "darkgreen",1), 
            lwd = c(NA, NA, 2, 2, 2), 
@@ -453,8 +457,10 @@ plot.gbp <- function(x, sort = TRUE, ...) {
              "Posterior sd \nof random effect", "Crossover"),
            seg.len = 0.5, bty = "n",xpd = TRUE)
   } else {
-    par(fig = c(0, 0.35, 0.5, 1), xaxs = "r", yaxs = "r", mai = c(0.4, 0.1, 0.5, 0), las = 1, ps = 13,
-        oma = c(0, 0, 0, 0), new = TRUE)  
+    old.par3 <- par(fig = c(0, 0.35, 0.5, 1), xaxs = "r", yaxs = "r", 
+                   mai = c(0.4, 0.1, 0.5, 0), las = 1, ps = 13,
+                   oma = c(0, 0, 0, 0), new = TRUE)
+    on.exit(par(old.par3))
     plot(1, type="n", axes=F, xlab="", ylab="")
     legend("topleft", pch = c(19, 1, NA, NA, NA,0), col = c(2, 1, 4,"darkviolet", "darkgreen",1), 
            lwd = c(NA, NA, 2, 2, 2), 
